@@ -30,6 +30,13 @@ impl Default for Transform {
     }
 }
 
+#[derive(Debug,Default,Serialize,Deserialize)]
+pub struct Translate {
+    pub universal: bool,
+    #[serde(rename="user-db")]
+    pub userdb: bool,
+}
+
 #[derive(Debug,Serialize,Deserialize)]
 pub struct Enrich {
     #[serde(rename="execve-env")] #[serde(default)]
@@ -57,6 +64,8 @@ pub struct Config {
     #[serde(default)]
     pub transform: Transform,
     #[serde(default)]
+    pub translate: Translate,
+    #[serde(default)]
     pub enrich: Enrich,
     #[serde(default)]
     pub filter: Filter,
@@ -75,12 +84,26 @@ impl Default for Config {
             },
             debuglog: None,
             transform: Transform::default(),
+            translate: Translate::default(),
             enrich: Enrich::default(),
             filter: Filter::default(),
         }
     }
 }
 
+impl std::fmt::Display for Config {
+    fn fmt(&self, fmt: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
+        write!(fmt, "(user={} directory={} file={} users={} size={} generations={})",
+               self.user.clone().unwrap_or("n/a".to_string()),
+               self.directory.clone().unwrap_or_else(||PathBuf::from(".")).display(),
+               self.auditlog.file.to_string_lossy(),
+               self.auditlog.users.clone().unwrap_or(vec!["n/a".to_string()]).join(","),
+               self.auditlog.size.unwrap_or(0),
+               self.auditlog.generations.unwrap_or(0)
+        )
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
