@@ -17,25 +17,16 @@ use caps::{Capability, CapSet};
 use caps::securebits::set_keepcaps;
 
 use serde::Serialize;
-use serde_json::{self,json};
+use serde_json;
 
-pub mod types;
-pub mod parser;
-pub mod quoted_string;
-pub mod coalesce;
-pub mod proc;
-pub mod rotate;
-pub mod config;
-pub mod constants;
-
-use coalesce::Coalesce;
-use rotate::FileRotate;
-use config::*;
+use laurel::coalesce::Coalesce;
+use laurel::rotate::FileRotate;
+use laurel::config::{ArrayOrString,Config};
 
 mod syslog {
     use std::ffi::CString;
     use std::mem::forget;
-    use libc::{openlog,syslog,LOG_DAEMON,LOG_WARNING,LOG_CRIT,LOG_PERROR};
+    use libc::{openlog,syslog,LOG_PERROR,LOG_DAEMON,LOG_INFO,LOG_WARNING,LOG_ERR,LOG_CRIT};
 
     pub fn init(progname: &String) {
         let ident = CString::new(progname.as_str()).unwrap();
@@ -44,21 +35,29 @@ mod syslog {
         // not be dropped.
         forget(ident);
     }
-
+    pub fn log_info(message: &str) {
+        let fs = CString::new("%s").unwrap();
+        let s = CString::new(message).unwrap();
+        unsafe { syslog(LOG_INFO | LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
+    }
     pub fn log_warn(message: &str) {
         let fs = CString::new("%s").unwrap();
         let s = CString::new(message).unwrap();
-        unsafe { syslog(LOG_WARNING|LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
+        unsafe { syslog(LOG_WARNING | LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
+    }
+    pub fn log_err(message: &str) {
+        let fs = CString::new("%s").unwrap();
+        let s = CString::new(message).unwrap();
+        unsafe { syslog(LOG_ERR | LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
     }
-
     pub fn log_crit(message: &str) {
         let fs = CString::new("%s").unwrap();
         let s = CString::new(message).unwrap();
-        unsafe { syslog(LOG_CRIT|LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
+        unsafe { syslog(LOG_CRIT | LOG_DAEMON, fs.as_ptr(), s.as_ptr()) };
     }
 }
 
-use syslog::{log_warn,log_crit};
+use syslog::{log_crit, log_err, log_info, log_warn};
 
 #[derive(Default,Serialize)]
 struct Stats { lines: u64, events: u64, errors: u64 }
@@ -122,7 +121,10 @@ fn run_app() -> Result<(), Box<dyn Error>> {
             if fs::metadata(&f_name)?.permissions().mode() & 0o002 != 0 {
                 return Err(format!("Config file {} must not be world-writable", f_name).into());
             }
-            toml::from_slice(&fs::read(&f_name)?)?
+            let lines = fs::read(&f_name)
+                .map_err(|e| format!("read {}: {}", f_name, e))?;
+            toml::from_slice(&lines)
+                .map_err(|e| format!("parse {}: {}", f_name, e))?
         },
         None => Config::default(),
     };
@@ -159,7 +161,7 @@ fn run_app() -> Result<(), Box<dyn Error>> {
     fs::set_permissions(&dir, PermissionsExt::from_mode(0o755))
         .map_err(|e| format!("chmod: {}: {}", dir.to_string_lossy(), e))?;
 
-    let mut logger = match &config.auditlog.file {
+    let logger = match &config.auditlog.file {
         p if p.as_os_str() == "-" => Logger { output: BufWriter::new(Box::new(io::stdout())) },
         p if p.has_root() && p.parent() != None => {
             return Err(format!("invalid file directory={} file={}",
@@ -192,28 +194,29 @@ fn run_app() -> Result<(), Box<dyn Error>> {
             Logger { output: BufWriter::new(Box::new(rot)) }
         }
     };
+    let logger = std::cell::RefCell::new(logger);
 
     if !Uid::effective().is_root() {
-        logger.log(&json!({"warning": "Not dropping privileges -- not running as root"}));
+        log_warn("Not dropping privileges -- not running as root");
     } else if runas_user.uid.is_root() {
-        logger.log(&json!({"warning": "Not dropping privileges -- no user configured"}));
+        log_warn("Not dropping privileges -- no user configured");
     } else if let Err(e) = drop_privileges(&runas_user) {
-        logger.log(&json!({"fatal": e.to_string()}));
+        // Logged to syslog by caller
         return Err(e);
     }
 
     // Initial setup is done at this point.
 
-    logger.log(&json!({
-        "notice": {
-            "program": &args[0],
-            "action": "start",
-            "euid": Uid::effective().as_raw(),
-            "version": env!("CARGO_PKG_VERSION"),
-            "config": &config
-        }}));
+    log_info(
+        &format!(
+            "Started {} running version {}",
+            &args[0],
+            env!("CARGO_PKG_VERSION")
+        )
+    );
+    log_info(&format!("Running with EUID {} using config {}", Uid::effective().as_raw(), &config));
 
-    let mut coalesce = Coalesce::default();
+    let mut coalesce = Coalesce::new( |e| logger.borrow_mut().log(e) );
     coalesce.execve_argv_list = config.transform.execve_argv.contains(&ArrayOrString::Array);
     coalesce.execve_argv_string = config.transform.execve_argv.contains(&ArrayOrString::String);
     coalesce.execve_env = config.enrich.execve_env.iter()
@@ -221,6 +224,9 @@ fn run_app() -> Result<(), Box<dyn Error>> {
         .collect();
     coalesce.populate_proc_table()
         .map_err(|e| format!("populate proc table: {}", e))?;
+    coalesce.translate_universal = config.translate.universal;
+    coalesce.translate_userdb = config.translate.userdb;
+
     let mut line: Vec<u8> = Vec::new();
     let mut stats = Stats::default();
 
@@ -234,21 +240,22 @@ fn run_app() -> Result<(), Box<dyn Error>> {
         }
         stats.lines+=1;
         match coalesce.process_line(line.clone()) {
-            Ok(Some(event)) => {
-                stats.events += 1;
-                logger.log(&event);
-            }
-            Ok(None) => (),
+            Ok(()) => (),
             Err(e) => {
                 stats.errors += 1;
-                let line = String::from_utf8_lossy(&line);
-                logger.log(&json!({"error": { "message": e.to_string(), "input": &line }}));
+                let line = String::from_utf8_lossy(&line).replace("\n", "");
+                log_err(&format!("Error {} processing msg: {}", e.to_string(), &line));
                 continue
             }
         };
     }
 
-    logger.log(&json!({"notice": { "program": &args[0], "action": "stop", "stats": &stats }}));
+    log_info(
+        &format!(
+            "Stopped {} processed {} lines {} events with {} errors in total",
+            &args[0], &stats.lines, &stats.events, &stats.errors
+        )
+    );
 
     Ok(())
 }
